@@ -31,7 +31,6 @@ def prepare_data(root, accelerometer=True, gyroscope=True, orientation=False, st
     subject_list = set()
     file_list = get_file_list(root, ext=".mat")
 
-    # for i, fpath in enumerate(file_list):
     pbar = tqdm(file_list, desc="Reading mat files ...")
     for i, fpath in enumerate(pbar):
         subject_name = re.search("(S[0-9]+_|[sS]troke[0-9]+)", fpath).group().replace("_", "").lower()
@@ -45,8 +44,6 @@ def prepare_data(root, accelerometer=True, gyroscope=True, orientation=False, st
         subject_list.add(subject_name)
 
         try:
-            # if verbose > 0:
-            #     print("Reading {} ... ({}/{}) {:.2f}% :: Subject name : {}".format(fpath, i+1, len(file_list), ((i+1)/len(file_list)*100), subject_name))
             csv, video, segment = read_mat_file(fpath)
 
             for sensor_data, label, name in zip(segment['segment_sensor_data'], segment['segment_label'], segment['segment_name']):
@@ -155,29 +152,13 @@ def make_training_data(data_root, save_root, window_size=300, stride=1, chunk_si
                        verbose=1):
     data, label, subjects, label_info, subject_list = prepare_data(data_root, merge_clap_null=merge_clap_null)
 
-    for i in tqdm(range(len(data))):
-        if np.sum(np.isnan(data[i].flatten())) > 0:
-            print("NaN exits prior to normalizing on {} idx".format(i))
-
     if normalize_axis:
         data = normalize_data(data, norm_max=normalize_max)
 
-    for i in tqdm(range(len(data))):
-        if np.sum(np.isnan(data[i].flatten())) > 0:
-            print("NaN exits post to normalizing on {} idx".format(i))
-
     training_data, training_label, training_subject, test_data, test_label, test_subject = \
         generate_training_test_data(data, label, subjects, subject_list, training_portion=training_portion,
                                     shuffle=shuffle, verbose=verbose)
 
-    for i, dd in enumerate(training_data):
-        if np.sum(np.isnan(dd.flatten())) > 0:
-            print("NaN Exist after generate training test! (training) on {}".format(i))
-
-    for i, dd in enumerate(test_data):
-        if np.sum(np.isnan(dd.flatten())) > 0:
-            print("NaN Exist after generate training test! (training) on {}".format(i))
-
     save_windowed_dataset_hdf5(training_data, training_label, test_data, test_label,
                                window_size=window_size, stride=stride, save_root=save_root,
                                chunk_size=chunk_size)
